@@ -18,7 +18,7 @@ class GUID(TypeDecorator):
     """
     impl = CHAR
 
-    python_type = type(b'')
+    python_type = type('')
 
     def load_dialect_impl(self, dialect):
         if dialect.name == 'postgresql':
@@ -30,13 +30,13 @@ class GUID(TypeDecorator):
         if value is None:
             return value
         elif dialect.name == 'postgresql':
-            return str(value)
+            return self.python_type(value)
         else:
             if not isinstance(value, uuid.UUID):
-                return str(uuid.UUID(value))
+                return self.python_type(uuid.UUID(value))
             else:
                 # hexstring
-                return str(value)
+                return self.python_type(value)
 
     def process_result_value(self, value, dialect):
         if value is None:
